@@ -1,21 +1,25 @@
-# -*- coding: utf-8 -*-
 """
     domonic.html
-    ~~~~~
+    ====================================
     Generate HTML using python 3
 """
 
-# from .dom import Element, Document
-from .javascript import *
-
-# from domonic import tag, closed_tag, tag_init
-# import domonic
-
+from domonic.javascript import URL
 from domonic.dom import Element, Document
 
 
 def render(inp, outp=''):
-    # print(inp)
+    """render
+
+    Renders the input to string or to a file.
+
+    Args:
+        inp (obj): A domonic tag. For example div()
+        outp (str): An optional output filename
+
+    Returns:
+        str: A HTML rendered string
+    """
     if outp != '':
         with open(outp, "w+") as f:
             f.write(str(inp))
@@ -61,6 +65,7 @@ class DomonicParseError(Exception):
 
 
 class tag(object):
+    """ The class from which all html tags extend """
 
     def __init__(self, *args, **kwargs):
         self.args = args
@@ -269,30 +274,27 @@ command = type('command', (closed_tag, Element), {'name': 'command', '__init__':
 main = type('command', (tag, Element), {'name': 'main', '__init__': tag_init})  # TODO - y was this missing?
 
 
-# TODO - this can't be added at the mo. need to push it
 class doctype():
+    """doctype
+
+    Returns:
+        str: <!DOCTYPE html>
+    """
     def __str__(self):
         return "<!DOCTYPE html>"
 
 
 class comment():
+    """comment
+
+    Args:
+        content (str): Message to be rendered inside the comment tag
+
+    Returns:
+        str: "<!-- {self.content} -->
+    """
     def __init__(self, content=""):
         self.content = content
 
     def __str__(self):
         return f"<!-- {self.content} -->"
-
-
-# output = render(
-#     html(
-#         head(
-#             style(),script(),
-#         ),
-#         body(
-#             div("hello world"),
-#             a("this is a link", _href="http://www.somesite.com", _style="font-size:10px;"),
-#             ol(''.join([f'{li()}' for thing in range(5)])),
-#             h1("test", _class="test"),
-#         )
-#     )
-# )
